@@ -17,6 +17,7 @@
 
 #include "gtkmmhello.h"
 #include <iostream>
+#include <libintl.h>
 
 GtkmmHello::GtkmmHello()
 : m_Button(gettext("Click Me"))
@@ -25,7 +26,7 @@ GtkmmHello::GtkmmHello()
   set_border_width(10);
 
   //Connect the button's "clicked" signal to the on_button_clicked() signal handler:
-  m_Button.signal_clicked().connect(slot(*this, &GtkmmHello::on_button_clicked) );
+  m_Button.signal_clicked().connect( sigc::mem_fun(*this, &GtkmmHello::on_button_clicked) );
   
   add(m_Button);
   show_all();
