@@ -16,14 +16,21 @@
 */
 
 #include "gtkmmhello.h"
-#include "gtkmm/main.h"
+#include <gtkmm/main.h>
+#include <libintl.h>
+#include <config.h>
 
 int main (int argc, char *argv[])
 {
   Gtk::Main kit(argc, argv);
 
+  bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+  textdomain(GETTEXT_PACKAGE);
+
   GtkmmHello window;
   kit.run(window);
 
   return 0;
 }
+
